cardinal_pythonlib
==================

Simple library functions used by other code, and some basic command-line tools.

By Rudolf Cardinal (rudolf@pobox.com)

Install with ``pip install cardinal_pythonlib``.

Documentation is at https://cardinalpythonlib.readthedocs.io/.
